==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTLabeledNode.h <==
// public abstract class soot.dava.internal.AST.ASTLabeledNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTNode

#include "soot/dava/internal/AST/ASTNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTLabeledNode_H_
#define _JC_soot_dava_internal_AST_ASTLabeledNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	_jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$refs	_jc_soot_dava_internal_AST_ASTLabeledNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs	_jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$object	_jc_soot_dava_internal_AST_ASTLabeledNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtable	_jc_soot_dava_internal_AST_ASTLabeledNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtype	_jc_soot_dava_internal_AST_ASTLabeledNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$_init$b31b1f14472e6740(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_SET_SETNodeLabel$object *_jc_soot_dava_internal_AST_ASTLabeledNode$method$get__5fLabel$a981b351ff011e6d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTLabeledNode$method$label__5ftoString$ce4ce72b9b1b428b(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *);
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$label__5ftoString$9d5d287d24b597c8(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_object *);
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$set__5fLabel$e4b7389b4694582a(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$get__5fLabel$a981b351ff011e6d;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$label__5ftoString$ce4ce72b9b1b428b;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$label__5ftoString$9d5d287d24b597c8;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$set__5fLabel$e4b7389b4694582a;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vmethods {
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*(*get__5fLabel$a981b351ff011e6d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *);
	struct _jc_java_lang_String$object	*(*label__5ftoString$ce4ce72b9b1b428b)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *);
	void	(*label__5ftoString$9d5d287d24b597c8)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_object *);
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
	void	(*set__5fLabel$e4b7389b4694582a)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs {
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$refs {
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTLabeledNode$object {
	_jc_soot_dava_internal_AST_ASTLabeledNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTLabeledNode$vtype _jc_soot_dava_internal_AST_ASTLabeledNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTLabeledNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTLabeledNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTLabeledNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTLabeledNode.h <==
// public abstract class soot.dava.internal.AST.ASTLabeledNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTNode

#include "soot/dava/internal/AST/ASTNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTLabeledNode_H_
#define _JC_soot_dava_internal_AST_ASTLabeledNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	_jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$refs	_jc_soot_dava_internal_AST_ASTLabeledNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs	_jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTLabeledNode$object	_jc_soot_dava_internal_AST_ASTLabeledNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtable	_jc_soot_dava_internal_AST_ASTLabeledNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtype	_jc_soot_dava_internal_AST_ASTLabeledNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$_init$b31b1f14472e6740(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_SET_SETNodeLabel$object *_jc_soot_dava_internal_AST_ASTLabeledNode$method$get__5fLabel$a981b351ff011e6d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTLabeledNode$method$label__5ftoString$ce4ce72b9b1b428b(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$label__5ftoString$9d5d287d24b597c8(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTLabeledNode$method$set__5fLabel$e4b7389b4694582a(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$get__5fLabel$a981b351ff011e6d;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$label__5ftoString$ce4ce72b9b1b428b;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$label__5ftoString$9d5d287d24b597c8;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTLabeledNode$method_info$set__5fLabel$e4b7389b4694582a;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vmethods {
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*(*get__5fLabel$a981b351ff011e6d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*label__5ftoString$ce4ce72b9b1b428b)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *) _JC_JCNI_ATTR;
	void	(*label__5ftoString$9d5d287d24b597c8)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
	void	(*set__5fLabel$e4b7389b4694582a)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTLabeledNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTLabeledNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs {
	struct _jc_soot_dava_internal_SET_SETNodeLabel$object	*label;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$refs {
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTLabeledNode$object {
	_jc_soot_dava_internal_AST_ASTLabeledNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTLabeledNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTLabeledNode$vtype _jc_soot_dava_internal_AST_ASTLabeledNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTLabeledNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTLabeledNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTLabeledNode_H_ */
